
.. include:: ../README.rst


Introduction and Basics
=======================

.. toctree::
   :maxdepth: 2

   basics
   schemas
   externalization
   internalization
   special_attributes
   glossary
   changelog


API Details
===========

.. toctree::
   :maxdepth: 2

   api/index


====================
 Indices and tables
====================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
